@@ -10,27 +10,43 @@ except:
         from cluster import Cluster
         from cross_correlation_graph import CrossCorrelationGraph
         from fingerprint import Fingerprint
-    except:
-        pass
+    except Exception as e:
+        raise ValueError(e)
 
 class FingerprintGenerator(object):
+    """Generator of FlowPrint Fingerprint objects from flows
+
+        Attributes
+        ----------
+        batch : float
+            Threshold for the batch size in seconds
+
+        window : float
+            Threshold for the window size in seconds
+
+        correlation : float
+            Threshold for the minimum required correlation
+
+        similarity : float
+            Threshold for the minimum required similarity
+    """
 
     def __init__(self, batch=300, window=30, correlation=0.1, similarity=0.9):
-        """Generate FlowPrint Fingerprint objects from flows.
+        """Generate FlowPrint Fingerprint objects from flows
 
             Parameters
             ----------
             batch : float, default=300
-                Threshold for the batch size in seconds.
+                Threshold for the batch size in seconds
 
             window : float, default=30
-                Threshold for the window size in seconds.
+                Threshold for the window size in seconds
 
             correlation : float, default=0.1
                 Threshold for the minimum required correlation
 
             similarity : float, default=0.9
-                Threshold for the minimum required similarity.
+                Threshold for the minimum required similarity
             """
         # Set FlowPrint parameters
         self.batch       = batch
@@ -81,7 +97,7 @@ class FingerprintGenerator(object):
         y = y[sort_time]
 
         # Divide X and y in batches of size batch
-        sort_batch = np.array([x.time_start() for x in X])
+        sort_batch = np.array([x.time_start for x in X])
         # Compute number of required batches
         if sort_batch.shape[0]:
             batches = int(
@@ -178,8 +194,8 @@ class FingerprintGenerator(object):
 
         # Apply mapping
         prediction = np.array([
-            mapping_fingerprints.get(x.destination(),
-            mapping_fingerprints.get(x.certificate(),
+            mapping_fingerprints.get(x.destination,
+            mapping_fingerprints.get(x.certificate,
             Fingerprint())) for x in X
         ])
 
@@ -227,7 +243,7 @@ class FingerprintGenerator(object):
         X = X[sort_time]
         y = y[sort_time]
         # Get timestamps
-        timestamps = np.asarray([x.time_start() for x in X])
+        timestamps = np.asarray([x.time_start for x in X])
 
         ####################################################################
         #               Assign closest fingerprints in time                #
@@ -251,8 +267,8 @@ class FingerprintGenerator(object):
             before = min(block) - 1
             after  = max(block) + 1
             # Get timestamps before and after block
-            ts_before = X[before].time_start() if before >= 0          else float('inf')
-            ts_after  = X[after ].time_start() if after  <  X.shape[0] else float('inf')
+            ts_before = X[before].time_start if before >= 0          else float('inf')
+            ts_after  = X[after ].time_start if after  <  X.shape[0] else float('inf')
             # Get fingerprints before and after block
             fp_before = y[before] if before >= 0          else Fingerprint()
             fp_after  = y[after ] if after  <  X.shape[0] else Fingerprint()
